SystemOrganization addCategory: #'HM4-PokerDice'!

TestCase subclass: #PokerDiceGameTest
	instanceVariableNames: 'newGame'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HM4-PokerDice'!

!PokerDiceGameTest methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/22/2013 13:41'!
setUp
	newGame := PokerDiceGame new.! !

!PokerDiceGameTest methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 19:02'!
testNewGameConditions
	self assert: newGame creditsRemaining = PokerDiceGame startingCredits.
	self assert: newGame throwsInRoundRemaining = PokerDiceGame throwsPerRound.
	self assert: newGame currentRound = 1.
	self assert: newGame playerCanSelectDice = false.! !

!PokerDiceGameTest methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 19:06'!
testPayPlayer
	| hand |
	hand := Hand new.
	hand fixDice: #(2 2 2 2 1).
	1 to: 2 do: [ :i | newGame playerThrew ].
	newGame fixHand: #(2 2 2 2 1).
	self assert: newGame playerCanSelectDice = true.
	newGame playerAcceptsPayment.
	self assert: (newGame throwsInRoundRemaining) = 0.
	self assert: (newGame currentRound = 1).
	self assert: (newGame creditsRemaining) = (PokerDiceGame startingCredits - PokerDiceGame costToPlayRound + hand payout).
	self assert: newGame playerCanSelectDice = false.
	! !

!PokerDiceGameTest methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 19:06'!
testPlayTwoRounds
	| hand round1StartingCredits round2StartingCredits |
	hand := Hand new.
	
	hand fixDice: #(2 2 2 2 1).
	round1StartingCredits := newGame creditsRemaining.
	1 to: 2 do: [ :i | newGame playerThrew ].
	newGame fixHand: #(2 2 2 2 1).
	self assert: newGame playerCanSelectDice = true.
	newGame playerAcceptsPayment.
	self assert: (newGame throwsInRoundRemaining) = 0.
	self assert: (newGame currentRound = 1).
	self assert: (newGame creditsRemaining) = (round1StartingCredits - PokerDiceGame costToPlayRound + hand payout).
	self assert: newGame playerCanSelectDice = false.
	
	hand fixDice: #(2 2 2 1 1).
	round2StartingCredits := newGame creditsRemaining.
	1 to: 2 do: [ :i | newGame playerThrew ].
	newGame fixHand: #(2 2 2 1 1).
	self assert: newGame playerCanSelectDice = true.
	newGame playerAcceptsPayment.
	self assert: (newGame throwsInRoundRemaining) = 0.
	self assert: (newGame currentRound = 2).
	self assert: (newGame creditsRemaining) = (round2StartingCredits - PokerDiceGame costToPlayRound + hand payout).
	self assert: newGame playerCanSelectDice = false.! !

!PokerDiceGameTest methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 19:05'!
testThrowFourTimes
	| hand |
	hand := Hand new.
	hand fixDice: #(2 2 2 2 1).
	1 to: 4 do: [ :i | newGame fixHand: #(2 2 2 2 1).  newGame playerThrew ].
	self assert: (newGame throwsInRoundRemaining) = (PokerDiceGame throwsPerRound - 1).
	self assert: (newGame currentRound = 2).
	self assert: (newGame creditsRemaining) = ((PokerDiceGame startingCredits) + (hand payout) - (PokerDiceGame costToPlayRound) - (PokerDiceGame costToPlayRound)).
	self assert: newGame playerCanSelectDice = true.! !

!PokerDiceGameTest methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 19:03'!
testThrowOnce
	newGame playerThrew.
	self assert: (newGame throwsInRoundRemaining) = (PokerDiceGame throwsPerRound - 1).
	self assert: (newGame currentRound = 1).
	self assert: newGame playerCanSelectDice = true.! !

!PokerDiceGameTest methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 19:46'!
testThrowThreeTimes
	| hand |
	hand := Hand new.
	hand fixDice: #(2 2 2 2 1).
	1 to: 3 do: [ :i | newGame fixHand: #(2 2 2 2 1).  newGame playerThrew ].
	self assert: (newGame throwsInRoundRemaining) = (PokerDiceGame throwsPerRound - 3).
	self assert: newGame playerCanSelectDice = true.
	newGame playerAcceptsPayment.
	self assert: (newGame throwsInRoundRemaining) = (PokerDiceGame throwsPerRound - 3).
	self assert: (newGame currentRound = 1).
	self assert: (newGame creditsRemaining) = (PokerDiceGame startingCredits - PokerDiceGame costToPlayRound + hand payout).
	self assert: newGame playerCanSelectDice = false.! !

!PokerDiceGameTest methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 19:04'!
testThrowTwice
	| hand |
	hand := Hand new.
	1 to: 2 do: [ :i | newGame playerThrew ].
	self assert: (newGame throwsInRoundRemaining) = (PokerDiceGame throwsPerRound - 2).
	self assert: (newGame currentRound = 1).
	self assert: newGame playerCanSelectDice = true.
	newGame playerAcceptsPayment.
	self assert: (newGame throwsInRoundRemaining) = 0.
	self assert: (newGame currentRound = 1).
	self assert: newGame playerCanSelectDice = false.
	! !

DieView subclass: #GameDieView
	instanceVariableNames: 'marked canBeMarked'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HM4-PokerDice'!

!GameDieView methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 19:52'!
disableMarking
	canBeMarked := false.
	self unmark.! !

!GameDieView methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 19:50'!
enableMarking
	canBeMarked := true.! !

!GameDieView methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 19:50'!
handlesMouseDown: evt
	canBeMarked
		ifTrue: [ ^ super handlesMouseDown: evt ]
		ifFalse: [ ^ canBeMarked ]
	! !

!GameDieView methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 19:50'!
initialize
	super initialize.
	marked := false.
	canBeMarked := true.! !

!GameDieView methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/21/2013 14:10'!
isMarked
	^ marked.! !

!GameDieView methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 19:10'!
mark
	marked := true.
	self updateMarking.! !

!GameDieView methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/21/2013 14:05'!
mouseDown: event 
	marked := marked not.
	self updateMarking.! !

!GameDieView methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 19:10'!
unmark
	marked := false.
	self updateMarking.! !

!GameDieView methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/21/2013 14:16'!
updateMarking
	marked
	ifTrue: [ self borderColor: Color yellow ; color: Color blue ] 
	ifFalse: [ self borderColor: Color black ; color: self defaultColor ]! !

SimpleButtonMorph subclass: #PokerDiceGameButton
	instanceVariableNames: 'enabled'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HM4-PokerDice'!

!PokerDiceGameButton methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/25/2013 13:55'!
disable
	enabled := false.
	self color: Color lightGray.! !

!PokerDiceGameButton methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 19:34'!
enable
	enabled := true.
	self color: Color green.! !

!PokerDiceGameButton methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 19:27'!
handlesMouseDown: evt
	^ enabled! !

!PokerDiceGameButton methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 19:34'!
initialize
	super initialize.
	self enable.! !

AlignmentMorph subclass: #GameBannerView
	instanceVariableNames: 'banner'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HM4-PokerDice'!

!GameBannerView methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/25/2013 14:00'!
initialize
	super initialize.
	banner := (StringMorph new) contents: 'Poker Dice'.
	! !

AlignmentMorph subclass: #GameBoardView
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HM4-PokerDice'!

!GameBoardView methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/25/2013 13:54'!
initialize
	super initialize.
	self borderWidth: 1.
	self shrinkWrap.
	self cornerStyle: #rounded! !

!GameBoardView methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/25/2013 13:54'!
shrinkWrap
	self hResizing: #shrinkWrap.
	self vResizing: #shrinkWrap! !

AlignmentMorph subclass: #GameControlView
	instanceVariableNames: 'throwButton acceptPaymentButton'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HM4-PokerDice'!

!GameControlView methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 19:35'!
disableAcceptButton
	acceptPaymentButton disable.! !

!GameControlView methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 19:35'!
disableThrowButton
	throwButton disable.! !

!GameControlView methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 19:35'!
enableAcceptButton
	acceptPaymentButton enable.! !

!GameControlView methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 19:35'!
enableThrowButton
	throwButton enable.! !

!GameControlView methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/25/2013 13:39'!
initialize
	| buttonColumn |
	super initialize.
	self hResizing: #shrinkWrap.
	self vResizing: #shrinkWrap.
	self cornerStyle: #rounded.
	
	buttonColumn := (AlignmentMorph newColumn).
	buttonColumn cornerStyle: #rounded.
	buttonColumn addMorphBack: (AlignmentMorph newSpacer: (buttonColumn defaultColor)).
	acceptPaymentButton := PokerDiceGameButton newWithLabel: 'accept payment'.
	acceptPaymentButton cornerStyle: #rounded.
	buttonColumn addMorphBack: acceptPaymentButton.
	buttonColumn addMorphBack: (AlignmentMorph newSpacer: (buttonColumn defaultColor)).
	throwButton := PokerDiceGameButton newWithLabel: 'throw dice'.
	throwButton cornerStyle: #rounded.
	buttonColumn addMorphBack: throwButton.
	buttonColumn addMorphBack: (AlignmentMorph newSpacer: (buttonColumn defaultColor)).
	self addMorphBack: buttonColumn.! !

!GameControlView methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/23/2013 15:46'!
setAcceptPaymentButtonTarget: target atSelector: selector
	acceptPaymentButton target: target; actionSelector: selector.! !

!GameControlView methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/23/2013 13:34'!
setThrowButtonTarget: target atSelector: selector
	throwButton target: target; actionSelector: selector.! !

AlignmentMorph subclass: #GameDiceView
	instanceVariableNames: 'game dieViews'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HM4-PokerDice'!

!GameDiceView class methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/22/2013 21:10'!
makeFromHand: aHand
	
"	buttonColumn := (AlignmentMorph newColumn).
	buttonColumn addMorphBack: (AlignmentMorph newSpacer: (Color gray)).
	newGameButton := SimpleButtonMorph newWithLabel: 'new game'.
	buttonColumn addMorphBack: newGameButton.
	buttonColumn addMorphBack: (AlignmentMorph newSpacer: (Color gray)).
	throwButton := SimpleButtonMorph newWithLabel: 'throw dice'.
	buttonColumn addMorphBack: throwButton.
	buttonColumn addMorphBack: (AlignmentMorph newSpacer: (Color gray)).
	self addMorphBack: buttonColumn."! !

!GameDiceView methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/25/2013 13:38'!
initialize
	super initialize.
	self hResizing: #shrinkWrap.
	self vResizing: #shrinkWrap.
	self cornerStyle: #rounded.! !

!GameDiceView methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 19:54'!
setGame: aGame
	game := aGame.
	dieViews := Array new: (game handSize).
	1 to: game handSize do: [ :i | dieViews at: i put: GameDieView new ].
	1 to: game handSize do: [ :i | (dieViews at: i) model: (game hand dice at: i) ].
	1 to: game handSize do: [ :i | self addMorphBack: (dieViews at: i) ].
	self update.! !

!GameDiceView methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 19:09'!
throwDice
	game playerCanSelectDice 
		ifTrue: [1 to: game handSize do: [ :i | (dieViews at: i) isMarked ifFalse: [ (dieViews at: i) throwDie ] ]]
		ifFalse: [1 to: game handSize do: [ :i | (dieViews at: i) throwDie ]].
	! !

!GameDiceView methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 19:43'!
unmarkDice
		1 to: game handSize do: [ :i | (dieViews at: i) unmark ].
	! !

!GameDiceView methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 19:52'!
update
	game playerCanSelectDice
		ifTrue: [ 1 to: game handSize do: [ :i | (dieViews at: i) enableMarking ] ]
		ifFalse: [ 1 to: game handSize do: [ :i | (dieViews at: i) disableMarking ] ]
	! !

AlignmentMorph subclass: #GameStateView
	instanceVariableNames: 'roundLabel roundData throwsLabel throwsData creditLabel creditData game payoutLabel payoutData'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HM4-PokerDice'!

!GameStateView methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/25/2013 13:42'!
initialize
	| titleColumn dataColumn |
	super initialize.
	self hResizing: #shrinkWrap.
	self vResizing: #shrinkWrap.
	self cornerStyle: #rounded.
	
	titleColumn := (AlignmentMorph newColumn).
	titleColumn cornerStyle: #rounded.
	roundLabel := (StringMorph new) contents: 'round'.
	titleColumn addMorphBack: (self wrapInContainer: roundLabel).
	throwsLabel := (StringMorph new) contents: 'throws remaining'.
	titleColumn addMorphBack: (self wrapInContainer: throwsLabel).
	creditLabel := (StringMorph new) contents: 'credit'.
	titleColumn addMorphBack: (self wrapInContainer: creditLabel).
	payoutLabel := (StringMorph new) contents: 'hand payout'.
	titleColumn addMorphBack: (self wrapInContainer: payoutLabel).
	self addMorphBack: titleColumn.
	
	dataColumn := AlignmentMorph newColumn.
	dataColumn cornerStyle: #rounded.
	roundData := (StringMorph new) contents: ''.
	dataColumn addMorphBack: (self wrapInContainer: roundData).
	throwsData :=  (StringMorph new) contents: ''.
	dataColumn addMorphBack: (self wrapInContainer: throwsData).
	creditData := (StringMorph new) contents: ''.
	dataColumn addMorphBack: (self wrapInContainer: creditData).
	payoutData := (StringMorph new) contents: ''.
	dataColumn addMorphBack: (self wrapInContainer: payoutData).
	self addMorphBack: dataColumn.! !

!GameStateView methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/23/2013 13:29'!
setCredits: credits
	creditData contents: credits asString.! !

!GameStateView methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/23/2013 13:30'!
setCurrentRound: round
	roundData contents: round asString.! !

!GameStateView methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 19:12'!
setGame: aGame.
	game := aGame.! !

!GameStateView methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 20:30'!
setHandPayout: payout
	payoutData contents: payout asString.! !

!GameStateView methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/23/2013 13:30'!
setThrowsRemaining: throws
	throwsData contents: throws asString.! !

!GameStateView methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 20:30'!
update
	self setCredits: game creditsRemaining.
	self setCurrentRound: game currentRound.
	self setThrowsRemaining: game throwsInRoundRemaining.
	self setHandPayout: game hand payout.! !

!GameStateView methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/22/2013 20:47'!
wrapInContainer: aMorph
	^ ((AlignmentMorph newRow) borderWidth: 2) addMorph: aMorph.! !

Object subclass: #PokerDiceGame
	instanceVariableNames: 'hand currentState oneState twoState threeState zeroState acceptState creditsRemaining roundsPlayed'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HM4-PokerDice'!

!PokerDiceGame class methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/22/2013 14:22'!
costToPlayRound
	^ 10! !

!PokerDiceGame class methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/22/2013 13:46'!
startingCredits
	^ 100! !

!PokerDiceGame class methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/22/2013 13:49'!
throwsPerRound
	^ 3! !

!PokerDiceGame methodsFor: 'throw state' stamp: 'CameronRieck 2/24/2013 18:44'!
acceptState
	^ acceptState! !

!PokerDiceGame methodsFor: 'private' stamp: 'CameronRieck 2/23/2013 16:37'!
chargePlayerForRound
	creditsRemaining := creditsRemaining - PokerDiceGame costToPlayRound! !

!PokerDiceGame methodsFor: 'game state' stamp: 'CameronRieck 2/22/2013 13:44'!
creditsRemaining
	^ creditsRemaining! !

!PokerDiceGame methodsFor: 'game state' stamp: 'CameronRieck 2/22/2013 14:05'!
currentRound
	^ roundsPlayed + 1! !

!PokerDiceGame methodsFor: 'throw state' stamp: 'CameronRieck 2/23/2013 15:10'!
currentState
	^ currentState! !

!PokerDiceGame methodsFor: 'private' stamp: 'CameronRieck 2/22/2013 14:26'!
fixHand: diceValues
	hand fixDice: diceValues! !

!PokerDiceGame methodsFor: 'private' stamp: 'CameronRieck 2/21/2013 18:47'!
hand
	^ hand! !

!PokerDiceGame methodsFor: 'private' stamp: 'CameronRieck 2/23/2013 15:41'!
handSize
	^ hand dice size! !

!PokerDiceGame methodsFor: 'private' stamp: 'CameronRieck 2/22/2013 14:05'!
incrementRound
	roundsPlayed := roundsPlayed + 1.! !

!PokerDiceGame methodsFor: 'initialize-release' stamp: 'CameronRieck 2/24/2013 18:44'!
initialize
	super initialize.
	threeState := (ThreeThrowsRemainingState new) setGame: self.
	twoState := (TwoThrowsRemainingState new) setGame: self.
	oneState := (OneThrowRemainingState new) setGame: self.
	zeroState := (ZeroThrowsRemainingState new) setGame: self.
	acceptState := (PlayerAcceptedPaymentState new) setGame: self.
	currentState := threeState.
	
	self resetHand.
	self resetCreditsRemaining.
	self resetRoundsPlayed.! !

!PokerDiceGame methodsFor: 'throw state' stamp: 'CameronRieck 2/23/2013 15:01'!
oneState
	^ oneState! !

!PokerDiceGame methodsFor: 'game control' stamp: 'CameronRieck 2/24/2013 18:48'!
playerAcceptsPayment
	currentState accept! !

!PokerDiceGame methodsFor: 'game state' stamp: 'CameronRieck 2/24/2013 19:02'!
playerCanSelectDice
	^ currentState playerCanSelectDice! !

!PokerDiceGame methodsFor: 'game control' stamp: 'CameronRieck 2/23/2013 14:54'!
playerThrew
	currentState throw! !

!PokerDiceGame methodsFor: 'initialize-release' stamp: 'CameronRieck 2/22/2013 14:09'!
resetCreditsRemaining
	creditsRemaining := PokerDiceGame startingCredits! !

!PokerDiceGame methodsFor: 'initialize-release' stamp: 'CameronRieck 2/23/2013 15:39'!
resetHand
	hand := Hand new! !

!PokerDiceGame methodsFor: 'initialize-release' stamp: 'CameronRieck 2/22/2013 14:09'!
resetRoundsPlayed
	roundsPlayed := 0! !

!PokerDiceGame methodsFor: 'private' stamp: 'CameronRieck 2/23/2013 15:03'!
setGameState: aGameState
	currentState := aGameState! !

!PokerDiceGame methodsFor: 'throw state' stamp: 'CameronRieck 2/23/2013 15:01'!
threeState
	^ threeState! !

!PokerDiceGame methodsFor: 'game state' stamp: 'CameronRieck 2/23/2013 15:04'!
throwsInRoundRemaining
	^ currentState throwsRemaining! !

!PokerDiceGame methodsFor: 'throw state' stamp: 'CameronRieck 2/23/2013 15:01'!
twoState
	^ twoState! !

!PokerDiceGame methodsFor: 'private' stamp: 'CameronRieck 2/22/2013 14:23'!
updateCreditsWithCurrentPayout
	creditsRemaining := creditsRemaining + hand payout.! !

!PokerDiceGame methodsFor: 'throw state' stamp: 'CameronRieck 2/23/2013 15:01'!
zeroState
	^ zeroState! !

Object subclass: #PokerDiceGamePlayer
	instanceVariableNames: 'throwButton dieViews game gameStateView gameControlView gameDiceView gameBoardView'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HM4-PokerDice'!

!PokerDiceGamePlayer class methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/25/2013 13:33'!
withGame: aGame
	| newView |
	newView := PokerDiceGamePlayer new.
	newView game: aGame.
	^ newView.! !

!PokerDiceGamePlayer class methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/25/2013 13:34'!
withNewGame
	| newView |
	newView := PokerDiceGamePlayer new.
	newView game: (PokerDiceGame new).
	^ newView.! !

!PokerDiceGamePlayer methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 19:47'!
acceptPaymentButtonPressed
	game playerAcceptsPayment.
	gameStateView update.
	gameDiceView update.
	gameControlView disableAcceptButton.
	gameControlView enableThrowButton.! !

!PokerDiceGamePlayer methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/25/2013 13:54'!
game: aGame
	game := aGame.
	
	gameBoardView shrinkWrap.
	
	gameStateView setGame: game.
	gameStateView setThrowsRemaining: game throwsInRoundRemaining.
	gameStateView setCredits: game creditsRemaining.
	gameStateView setCurrentRound: game currentRound.
	gameBoardView addMorphBack: gameStateView.
	
	gameControlView setThrowButtonTarget: self atSelector: #throwButtonPressed.
	gameControlView setAcceptPaymentButtonTarget: self atSelector: #acceptPaymentButtonPressed.
	gameBoardView addMorphBack: gameControlView.

	gameDiceView setGame: game.
	gameBoardView addMorphBack: gameDiceView.! !

!PokerDiceGamePlayer methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/25/2013 13:50'!
initialize
	super initialize.
	gameStateView := GameStateView newRow.
	gameControlView := GameControlView newRow.
	gameControlView disableAcceptButton.
	gameControlView enableThrowButton.
	gameDiceView := GameDiceView newRow.
	gameBoardView := GameBoardView newColumn.! !

!PokerDiceGamePlayer methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/25/2013 13:49'!
show
	gameBoardView openInWorld.! !

!PokerDiceGamePlayer methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 19:39'!
throwButtonPressed
	gameDiceView throwDice.
	game playerThrew.
	gameStateView update.
	gameDiceView update.
	gameControlView enableAcceptButton.
	(game throwsInRoundRemaining = 0)
		ifTrue: [ gameControlView disableThrowButton ].! !

Object subclass: #PokerDiceGameState
	instanceVariableNames: 'game'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HM4-PokerDice'!

PokerDiceGameState subclass: #OneThrowRemainingState
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HM4-PokerDice'!

!OneThrowRemainingState methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 18:44'!
accept
	game updateCreditsWithCurrentPayout.
	game setGameState: game acceptState.! !

!OneThrowRemainingState methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 19:01'!
playerCanSelectDice
	^ true! !

!OneThrowRemainingState methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/23/2013 15:02'!
throw
	game setGameState: game zeroState.! !

!OneThrowRemainingState methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/23/2013 15:04'!
throwsRemaining
	^ 1! !

PokerDiceGameState subclass: #PlayerAcceptedPaymentState
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HM4-PokerDice'!

!PlayerAcceptedPaymentState methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/23/2013 16:35'!
accept
! !

!PlayerAcceptedPaymentState methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 19:00'!
playerCanSelectDice
	^ false! !

!PlayerAcceptedPaymentState methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 18:35'!
throw
	game chargePlayerForRound.
	game incrementRound.
	game setGameState: game twoState.! !

!PlayerAcceptedPaymentState methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/23/2013 16:36'!
throwsRemaining
	^ 0! !

!PokerDiceGameState methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/23/2013 14:40'!
accept
	self subclassResponsibility! !

!PokerDiceGameState methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 19:00'!
playerCanSelectDice
	self subclassResponsibility! !

!PokerDiceGameState methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/23/2013 14:37'!
setGame: aGame
	game := aGame! !

!PokerDiceGameState methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/23/2013 14:40'!
throw
	self subclassResponsibility! !

!PokerDiceGameState methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/23/2013 15:04'!
throwsRemaining
	self subclassResponsibility! !

PokerDiceGameState subclass: #ThreeThrowsRemainingState
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HM4-PokerDice'!

!ThreeThrowsRemainingState methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/23/2013 16:01'!
accept
	! !

!ThreeThrowsRemainingState methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 19:45'!
playerCanSelectDice
	^ false! !

!ThreeThrowsRemainingState methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 18:33'!
throw
	game chargePlayerForRound.
	game setGameState: game twoState.! !

!ThreeThrowsRemainingState methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/23/2013 15:04'!
throwsRemaining
	^ 3! !

PokerDiceGameState subclass: #TwoThrowsRemainingState
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HM4-PokerDice'!

!TwoThrowsRemainingState methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 18:45'!
accept
	game updateCreditsWithCurrentPayout.
	game setGameState: game acceptState.! !

!TwoThrowsRemainingState methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 19:01'!
playerCanSelectDice
	^ true! !

!TwoThrowsRemainingState methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/23/2013 15:02'!
throw
	game setGameState: game oneState.! !

!TwoThrowsRemainingState methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/23/2013 15:05'!
throwsRemaining
	^ 2! !

PokerDiceGameState subclass: #ZeroThrowsRemainingState
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HM4-PokerDice'!

!ZeroThrowsRemainingState methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 18:45'!
accept
	game updateCreditsWithCurrentPayout.
	game setGameState: game acceptState.! !

!ZeroThrowsRemainingState methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 19:45'!
playerCanSelectDice
	^ true! !

!ZeroThrowsRemainingState methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/24/2013 18:33'!
throw
	game playerAcceptsPayment.
	game chargePlayerForRound.
	game incrementRound.
	game setGameState: game twoState.! !

!ZeroThrowsRemainingState methodsFor: 'as yet unclassified' stamp: 'CameronRieck 2/23/2013 15:05'!
throwsRemaining
	^ 0! !
